resolve

package
v0.0.0-...-6b8ee43 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 25, 2026 License: AGPL-3.0 Imports: 9 Imported by: 0

Documentation

Overview

Package resolve selects the storage backend and default config filename for ze.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DefaultConfig

func DefaultConfig(store storage.Storage) string

DefaultConfig returns the config filename from meta/instance/name or "ze.conf".

func Storage

func Storage() (storage.Storage, error)

Storage creates the appropriate storage backend. Returns blob storage at {configDir}/database.zefs, or filesystem as fallback. On error, returns a filesystem backend and the error for the caller to handle.

Types

This section is empty.

Jump to